@@ -31,3 +31,14 @@ rows_bind <- function(list, list_names, col_name = "rowname", ...) {
     out
   }
 }
+
+#' Check if data has length and rows
+#'
+#' @param x A data frame or list to check
+#' @examples
+#' no_data_now(data.frame())
+#' no_data_now(data.frame(a = 1))
+#' @export
+no_data_now <- function(x) {
+  length(x) == 0 || (is.data.frame(x) & nrow(x) == 0)
+}
