@@ -1,7 +1,7 @@
 test_that("entrace returns empty and warns for short radius", {
   skip_if_no_key()
   Sys.sleep(0.11)
-  s <- expect_warning(bus_stops(38, -77, 0))
+  s <- expect_message(bus_stops(38, -77, 0))
   expect_length(s, 6)
   expect_s3_class(s, "data.frame")
   expect_equal(nrow(s), 0)
@@ -38,3 +38,15 @@ test_that("distances not returned without coordinates", {
   expect_s3_class(s, "data.frame")
   expect_true(all(is.na(s$Distance)))
 })
+
+test_that("empty tibble returned without bus stops", {
+  skip_if_no_key()
+  Sys.sleep(0.11)
+  s <- mockr::with_mock(
+    .env = as.environment("package:metro"),
+    `no_data_now` = function(x) TRUE,
+    expect_message(bus_stops())
+  )
+  expect_equal(nrow(s), 0)
+  expect_s3_class(s, "data.frame")
+})
